# coding: utf-8

# flake8: noqa

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# Define package exports
__all__ = [
    "APIKeysApi",
    "ActivitiesApi",
    "AlbumsApi",
    "AssetsApi",
    "AuthenticationApi",
    "AuthenticationAdminApi",
    "DeprecatedApi",
    "DownloadApi",
    "DuplicatesApi",
    "FacesApi",
    "JobsApi",
    "LibrariesApi",
    "MaintenanceAdminApi",
    "MapApi",
    "MemoriesApi",
    "NotificationsApi",
    "NotificationsAdminApi",
    "PartnersApi",
    "PeopleApi",
    "PluginsApi",
    "QueuesApi",
    "SearchApi",
    "ServerApi",
    "SessionsApi",
    "SharedLinksApi",
    "StacksApi",
    "SyncApi",
    "SystemConfigApi",
    "SystemMetadataApi",
    "TagsApi",
    "TimelineApi",
    "TrashApi",
    "UsersApi",
    "UsersAdminApi",
    "ViewsApi",
    "WorkflowsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "APIKeyCreateDto",
    "APIKeyCreateResponseDto",
    "APIKeyResponseDto",
    "APIKeyUpdateDto",
    "ActivityCreateDto",
    "ActivityResponseDto",
    "ActivityStatisticsResponseDto",
    "AddUsersDto",
    "AdminOnboardingUpdateDto",
    "AlbumResponseDto",
    "AlbumStatisticsResponseDto",
    "AlbumUserAddDto",
    "AlbumUserCreateDto",
    "AlbumUserResponseDto",
    "AlbumUserRole",
    "AlbumsAddAssetsDto",
    "AlbumsAddAssetsResponseDto",
    "AlbumsResponse",
    "AlbumsUpdate",
    "AssetBulkDeleteDto",
    "AssetBulkUpdateDto",
    "AssetBulkUploadCheckDto",
    "AssetBulkUploadCheckItem",
    "AssetBulkUploadCheckResponseDto",
    "AssetBulkUploadCheckResult",
    "AssetCopyDto",
    "AssetDeltaSyncDto",
    "AssetDeltaSyncResponseDto",
    "AssetFaceCreateDto",
    "AssetFaceDeleteDto",
    "AssetFaceResponseDto",
    "AssetFaceUpdateDto",
    "AssetFaceUpdateItem",
    "AssetFaceWithoutPersonResponseDto",
    "AssetFullSyncDto",
    "AssetIdsDto",
    "AssetIdsResponseDto",
    "AssetJobName",
    "AssetJobsDto",
    "AssetMediaResponseDto",
    "AssetMediaSize",
    "AssetMediaStatus",
    "AssetMetadataKey",
    "AssetMetadataResponseDto",
    "AssetMetadataUpsertDto",
    "AssetMetadataUpsertItemDto",
    "AssetOcrResponseDto",
    "AssetOrder",
    "AssetResponseDto",
    "AssetStackResponseDto",
    "AssetStatsResponseDto",
    "AssetTypeEnum",
    "AssetVisibility",
    "AudioCodec",
    "AuthStatusResponseDto",
    "AvatarUpdate",
    "BulkIdErrorReason",
    "BulkIdResponseDto",
    "BulkIdsDto",
    "CLIPConfig",
    "CQMode",
    "CastResponse",
    "CastUpdate",
    "ChangePasswordDto",
    "CheckExistingAssetsDto",
    "CheckExistingAssetsResponseDto",
    "Colorspace",
    "ContributorCountResponseDto",
    "CreateAlbumDto",
    "CreateLibraryDto",
    "CreateProfileImageResponseDto",
    "DatabaseBackupConfig",
    "DownloadArchiveInfo",
    "DownloadInfoDto",
    "DownloadResponse",
    "DownloadResponseDto",
    "DownloadUpdate",
    "DuplicateDetectionConfig",
    "DuplicateResponseDto",
    "EmailNotificationsResponse",
    "EmailNotificationsUpdate",
    "ExifResponseDto",
    "FaceDto",
    "FacialRecognitionConfig",
    "FoldersResponse",
    "FoldersUpdate",
    "ImageFormat",
    "JobCreateDto",
    "JobName",
    "JobSettingsDto",
    "LibraryResponseDto",
    "LibraryStatsResponseDto",
    "LicenseKeyDto",
    "LicenseResponseDto",
    "LogLevel",
    "LoginCredentialDto",
    "LoginResponseDto",
    "LogoutResponseDto",
    "MachineLearningAvailabilityChecksDto",
    "MaintenanceAction",
    "MaintenanceAuthDto",
    "MaintenanceLoginDto",
    "ManualJobName",
    "MapMarkerResponseDto",
    "MapReverseGeocodeResponseDto",
    "MemoriesResponse",
    "MemoriesUpdate",
    "MemoryCreateDto",
    "MemoryResponseDto",
    "MemorySearchOrder",
    "MemoryStatisticsResponseDto",
    "MemoryType",
    "MemoryUpdateDto",
    "MergePersonDto",
    "MetadataSearchDto",
    "NotificationCreateDto",
    "NotificationDeleteAllDto",
    "NotificationDto",
    "NotificationLevel",
    "NotificationType",
    "NotificationUpdateAllDto",
    "NotificationUpdateDto",
    "OAuthAuthorizeResponseDto",
    "OAuthCallbackDto",
    "OAuthConfigDto",
    "OAuthTokenEndpointAuthMethod",
    "OcrConfig",
    "OnThisDayDto",
    "OnboardingDto",
    "OnboardingResponseDto",
    "PartnerCreateDto",
    "PartnerDirection",
    "PartnerResponseDto",
    "PartnerUpdateDto",
    "PeopleResponse",
    "PeopleResponseDto",
    "PeopleUpdate",
    "PeopleUpdateDto",
    "PeopleUpdateItem",
    "Permission",
    "PersonCreateDto",
    "PersonResponseDto",
    "PersonStatisticsResponseDto",
    "PersonUpdateDto",
    "PersonWithFacesResponseDto",
    "PinCodeChangeDto",
    "PinCodeResetDto",
    "PinCodeSetupDto",
    "PlacesResponseDto",
    "PluginActionResponseDto",
    "PluginContextType",
    "PluginFilterResponseDto",
    "PluginResponseDto",
    "PluginTriggerResponseDto",
    "PluginTriggerType",
    "PurchaseResponse",
    "PurchaseUpdate",
    "QueueCommand",
    "QueueCommandDto",
    "QueueDeleteDto",
    "QueueJobResponseDto",
    "QueueJobStatus",
    "QueueName",
    "QueueResponseDto",
    "QueueResponseLegacyDto",
    "QueueStatisticsDto",
    "QueueStatusLegacyDto",
    "QueueUpdateDto",
    "QueuesResponseLegacyDto",
    "RandomSearchDto",
    "RatingsResponse",
    "RatingsUpdate",
    "ReactionLevel",
    "ReactionType",
    "ReverseGeocodingStateResponseDto",
    "SearchAlbumResponseDto",
    "SearchAssetResponseDto",
    "SearchExploreItem",
    "SearchExploreResponseDto",
    "SearchFacetCountResponseDto",
    "SearchFacetResponseDto",
    "SearchResponseDto",
    "SearchStatisticsResponseDto",
    "SearchSuggestionType",
    "ServerAboutResponseDto",
    "ServerApkLinksDto",
    "ServerConfigDto",
    "ServerFeaturesDto",
    "ServerMediaTypesResponseDto",
    "ServerPingResponse",
    "ServerStatsResponseDto",
    "ServerStorageResponseDto",
    "ServerThemeDto",
    "ServerVersionHistoryResponseDto",
    "ServerVersionResponseDto",
    "SessionCreateDto",
    "SessionCreateResponseDto",
    "SessionResponseDto",
    "SessionUnlockDto",
    "SessionUpdateDto",
    "SetMaintenanceModeDto",
    "SharedLinkCreateDto",
    "SharedLinkEditDto",
    "SharedLinkResponseDto",
    "SharedLinkType",
    "SharedLinksResponse",
    "SharedLinksUpdate",
    "SignUpDto",
    "SmartSearchDto",
    "SourceType",
    "StackCreateDto",
    "StackResponseDto",
    "StackUpdateDto",
    "StatisticsSearchDto",
    "SyncAckDeleteDto",
    "SyncAckDto",
    "SyncAckSetDto",
    "SyncAlbumDeleteV1",
    "SyncAlbumToAssetDeleteV1",
    "SyncAlbumToAssetV1",
    "SyncAlbumUserDeleteV1",
    "SyncAlbumUserV1",
    "SyncAlbumV1",
    "SyncAssetDeleteV1",
    "SyncAssetExifV1",
    "SyncAssetFaceDeleteV1",
    "SyncAssetFaceV1",
    "SyncAssetMetadataDeleteV1",
    "SyncAssetMetadataV1",
    "SyncAssetV1",
    "SyncAuthUserV1",
    "SyncEntityType",
    "SyncMemoryAssetDeleteV1",
    "SyncMemoryAssetV1",
    "SyncMemoryDeleteV1",
    "SyncMemoryV1",
    "SyncPartnerDeleteV1",
    "SyncPartnerV1",
    "SyncPersonDeleteV1",
    "SyncPersonV1",
    "SyncRequestType",
    "SyncStackDeleteV1",
    "SyncStackV1",
    "SyncStreamDto",
    "SyncUserDeleteV1",
    "SyncUserMetadataDeleteV1",
    "SyncUserMetadataV1",
    "SyncUserV1",
    "SystemConfigBackupsDto",
    "SystemConfigDto",
    "SystemConfigFFmpegDto",
    "SystemConfigFacesDto",
    "SystemConfigGeneratedFullsizeImageDto",
    "SystemConfigGeneratedImageDto",
    "SystemConfigImageDto",
    "SystemConfigJobDto",
    "SystemConfigLibraryDto",
    "SystemConfigLibraryScanDto",
    "SystemConfigLibraryWatchDto",
    "SystemConfigLoggingDto",
    "SystemConfigMachineLearningDto",
    "SystemConfigMapDto",
    "SystemConfigMetadataDto",
    "SystemConfigNewVersionCheckDto",
    "SystemConfigNightlyTasksDto",
    "SystemConfigNotificationsDto",
    "SystemConfigOAuthDto",
    "SystemConfigPasswordLoginDto",
    "SystemConfigReverseGeocodingDto",
    "SystemConfigServerDto",
    "SystemConfigSmtpDto",
    "SystemConfigSmtpTransportDto",
    "SystemConfigStorageTemplateDto",
    "SystemConfigTemplateEmailsDto",
    "SystemConfigTemplateStorageOptionDto",
    "SystemConfigTemplatesDto",
    "SystemConfigThemeDto",
    "SystemConfigTrashDto",
    "SystemConfigUserDto",
    "TagBulkAssetsDto",
    "TagBulkAssetsResponseDto",
    "TagCreateDto",
    "TagResponseDto",
    "TagUpdateDto",
    "TagUpsertDto",
    "TagsResponse",
    "TagsUpdate",
    "TemplateDto",
    "TemplateResponseDto",
    "TestEmailResponseDto",
    "TimeBucketAssetResponseDto",
    "TimeBucketsResponseDto",
    "ToneMapping",
    "TranscodeHWAccel",
    "TranscodePolicy",
    "TrashResponseDto",
    "UpdateAlbumDto",
    "UpdateAlbumUserDto",
    "UpdateAssetDto",
    "UpdateLibraryDto",
    "UsageByUserDto",
    "UserAdminCreateDto",
    "UserAdminDeleteDto",
    "UserAdminResponseDto",
    "UserAdminUpdateDto",
    "UserAvatarColor",
    "UserLicense",
    "UserMetadataKey",
    "UserPreferencesResponseDto",
    "UserPreferencesUpdateDto",
    "UserResponseDto",
    "UserStatus",
    "UserUpdateMeDto",
    "ValidateAccessTokenResponseDto",
    "ValidateLibraryDto",
    "ValidateLibraryImportPathResponseDto",
    "ValidateLibraryResponseDto",
    "VersionCheckStateResponseDto",
    "VideoCodec",
    "VideoContainer",
    "WorkflowActionItemDto",
    "WorkflowActionResponseDto",
    "WorkflowCreateDto",
    "WorkflowFilterItemDto",
    "WorkflowFilterResponseDto",
    "WorkflowResponseDto",
    "WorkflowUpdateDto",
]

# import apis into sdk package
from immich.client.api.api_keys_api import APIKeysApi as APIKeysApi
from immich.client.api.activities_api import ActivitiesApi as ActivitiesApi
from immich.client.api.albums_api import AlbumsApi as AlbumsApi
from immich.client.api.assets_api import AssetsApi as AssetsApi
from immich.client.api.authentication_api import AuthenticationApi as AuthenticationApi
from immich.client.api.authentication_admin_api import (
    AuthenticationAdminApi as AuthenticationAdminApi,
)
from immich.client.api.deprecated_api import DeprecatedApi as DeprecatedApi
from immich.client.api.download_api import DownloadApi as DownloadApi
from immich.client.api.duplicates_api import DuplicatesApi as DuplicatesApi
from immich.client.api.faces_api import FacesApi as FacesApi
from immich.client.api.jobs_api import JobsApi as JobsApi
from immich.client.api.libraries_api import LibrariesApi as LibrariesApi
from immich.client.api.maintenance_admin_api import (
    MaintenanceAdminApi as MaintenanceAdminApi,
)
from immich.client.api.map_api import MapApi as MapApi
from immich.client.api.memories_api import MemoriesApi as MemoriesApi
from immich.client.api.notifications_api import NotificationsApi as NotificationsApi
from immich.client.api.notifications_admin_api import (
    NotificationsAdminApi as NotificationsAdminApi,
)
from immich.client.api.partners_api import PartnersApi as PartnersApi
from immich.client.api.people_api import PeopleApi as PeopleApi
from immich.client.api.plugins_api import PluginsApi as PluginsApi
from immich.client.api.queues_api import QueuesApi as QueuesApi
from immich.client.api.search_api import SearchApi as SearchApi
from immich.client.api.server_api import ServerApi as ServerApi
from immich.client.api.sessions_api import SessionsApi as SessionsApi
from immich.client.api.shared_links_api import SharedLinksApi as SharedLinksApi
from immich.client.api.stacks_api import StacksApi as StacksApi
from immich.client.api.sync_api import SyncApi as SyncApi
from immich.client.api.system_config_api import SystemConfigApi as SystemConfigApi
from immich.client.api.system_metadata_api import SystemMetadataApi as SystemMetadataApi
from immich.client.api.tags_api import TagsApi as TagsApi
from immich.client.api.timeline_api import TimelineApi as TimelineApi
from immich.client.api.trash_api import TrashApi as TrashApi
from immich.client.api.users_api import UsersApi as UsersApi
from immich.client.api.users_admin_api import UsersAdminApi as UsersAdminApi
from immich.client.api.views_api import ViewsApi as ViewsApi
from immich.client.api.workflows_api import WorkflowsApi as WorkflowsApi

# import ApiClient
from immich.client.api_response import ApiResponse as ApiResponse
from immich.client.api_client import ApiClient as ApiClient
from immich.client.configuration import Configuration as Configuration
from immich.client.exceptions import OpenApiException as OpenApiException
from immich.client.exceptions import ApiTypeError as ApiTypeError
from immich.client.exceptions import ApiValueError as ApiValueError
from immich.client.exceptions import ApiKeyError as ApiKeyError
from immich.client.exceptions import ApiAttributeError as ApiAttributeError
from immich.client.exceptions import ApiException as ApiException

# import models into sdk package
from immich.client.models.api_key_create_dto import APIKeyCreateDto as APIKeyCreateDto
from immich.client.models.api_key_create_response_dto import (
    APIKeyCreateResponseDto as APIKeyCreateResponseDto,
)
from immich.client.models.api_key_response_dto import (
    APIKeyResponseDto as APIKeyResponseDto,
)
from immich.client.models.api_key_update_dto import APIKeyUpdateDto as APIKeyUpdateDto
from immich.client.models.activity_create_dto import (
    ActivityCreateDto as ActivityCreateDto,
)
from immich.client.models.activity_response_dto import (
    ActivityResponseDto as ActivityResponseDto,
)
from immich.client.models.activity_statistics_response_dto import (
    ActivityStatisticsResponseDto as ActivityStatisticsResponseDto,
)
from immich.client.models.add_users_dto import AddUsersDto as AddUsersDto
from immich.client.models.admin_onboarding_update_dto import (
    AdminOnboardingUpdateDto as AdminOnboardingUpdateDto,
)
from immich.client.models.album_response_dto import AlbumResponseDto as AlbumResponseDto
from immich.client.models.album_statistics_response_dto import (
    AlbumStatisticsResponseDto as AlbumStatisticsResponseDto,
)
from immich.client.models.album_user_add_dto import AlbumUserAddDto as AlbumUserAddDto
from immich.client.models.album_user_create_dto import (
    AlbumUserCreateDto as AlbumUserCreateDto,
)
from immich.client.models.album_user_response_dto import (
    AlbumUserResponseDto as AlbumUserResponseDto,
)
from immich.client.models.album_user_role import AlbumUserRole as AlbumUserRole
from immich.client.models.albums_add_assets_dto import (
    AlbumsAddAssetsDto as AlbumsAddAssetsDto,
)
from immich.client.models.albums_add_assets_response_dto import (
    AlbumsAddAssetsResponseDto as AlbumsAddAssetsResponseDto,
)
from immich.client.models.albums_response import AlbumsResponse as AlbumsResponse
from immich.client.models.albums_update import AlbumsUpdate as AlbumsUpdate
from immich.client.models.asset_bulk_delete_dto import (
    AssetBulkDeleteDto as AssetBulkDeleteDto,
)
from immich.client.models.asset_bulk_update_dto import (
    AssetBulkUpdateDto as AssetBulkUpdateDto,
)
from immich.client.models.asset_bulk_upload_check_dto import (
    AssetBulkUploadCheckDto as AssetBulkUploadCheckDto,
)
from immich.client.models.asset_bulk_upload_check_item import (
    AssetBulkUploadCheckItem as AssetBulkUploadCheckItem,
)
from immich.client.models.asset_bulk_upload_check_response_dto import (
    AssetBulkUploadCheckResponseDto as AssetBulkUploadCheckResponseDto,
)
from immich.client.models.asset_bulk_upload_check_result import (
    AssetBulkUploadCheckResult as AssetBulkUploadCheckResult,
)
from immich.client.models.asset_copy_dto import AssetCopyDto as AssetCopyDto
from immich.client.models.asset_delta_sync_dto import (
    AssetDeltaSyncDto as AssetDeltaSyncDto,
)
from immich.client.models.asset_delta_sync_response_dto import (
    AssetDeltaSyncResponseDto as AssetDeltaSyncResponseDto,
)
from immich.client.models.asset_face_create_dto import (
    AssetFaceCreateDto as AssetFaceCreateDto,
)
from immich.client.models.asset_face_delete_dto import (
    AssetFaceDeleteDto as AssetFaceDeleteDto,
)
from immich.client.models.asset_face_response_dto import (
    AssetFaceResponseDto as AssetFaceResponseDto,
)
from immich.client.models.asset_face_update_dto import (
    AssetFaceUpdateDto as AssetFaceUpdateDto,
)
from immich.client.models.asset_face_update_item import (
    AssetFaceUpdateItem as AssetFaceUpdateItem,
)
from immich.client.models.asset_face_without_person_response_dto import (
    AssetFaceWithoutPersonResponseDto as AssetFaceWithoutPersonResponseDto,
)
from immich.client.models.asset_full_sync_dto import (
    AssetFullSyncDto as AssetFullSyncDto,
)
from immich.client.models.asset_ids_dto import AssetIdsDto as AssetIdsDto
from immich.client.models.asset_ids_response_dto import (
    AssetIdsResponseDto as AssetIdsResponseDto,
)
from immich.client.models.asset_job_name import AssetJobName as AssetJobName
from immich.client.models.asset_jobs_dto import AssetJobsDto as AssetJobsDto
from immich.client.models.asset_media_response_dto import (
    AssetMediaResponseDto as AssetMediaResponseDto,
)
from immich.client.models.asset_media_size import AssetMediaSize as AssetMediaSize
from immich.client.models.asset_media_status import AssetMediaStatus as AssetMediaStatus
from immich.client.models.asset_metadata_key import AssetMetadataKey as AssetMetadataKey
from immich.client.models.asset_metadata_response_dto import (
    AssetMetadataResponseDto as AssetMetadataResponseDto,
)
from immich.client.models.asset_metadata_upsert_dto import (
    AssetMetadataUpsertDto as AssetMetadataUpsertDto,
)
from immich.client.models.asset_metadata_upsert_item_dto import (
    AssetMetadataUpsertItemDto as AssetMetadataUpsertItemDto,
)
from immich.client.models.asset_ocr_response_dto import (
    AssetOcrResponseDto as AssetOcrResponseDto,
)
from immich.client.models.asset_order import AssetOrder as AssetOrder
from immich.client.models.asset_response_dto import AssetResponseDto as AssetResponseDto
from immich.client.models.asset_stack_response_dto import (
    AssetStackResponseDto as AssetStackResponseDto,
)
from immich.client.models.asset_stats_response_dto import (
    AssetStatsResponseDto as AssetStatsResponseDto,
)
from immich.client.models.asset_type_enum import AssetTypeEnum as AssetTypeEnum
from immich.client.models.asset_visibility import AssetVisibility as AssetVisibility
from immich.client.models.audio_codec import AudioCodec as AudioCodec
from immich.client.models.auth_status_response_dto import (
    AuthStatusResponseDto as AuthStatusResponseDto,
)
from immich.client.models.avatar_update import AvatarUpdate as AvatarUpdate
from immich.client.models.bulk_id_error_reason import (
    BulkIdErrorReason as BulkIdErrorReason,
)
from immich.client.models.bulk_id_response_dto import (
    BulkIdResponseDto as BulkIdResponseDto,
)
from immich.client.models.bulk_ids_dto import BulkIdsDto as BulkIdsDto
from immich.client.models.clip_config import CLIPConfig as CLIPConfig
from immich.client.models.cq_mode import CQMode as CQMode
from immich.client.models.cast_response import CastResponse as CastResponse
from immich.client.models.cast_update import CastUpdate as CastUpdate
from immich.client.models.change_password_dto import (
    ChangePasswordDto as ChangePasswordDto,
)
from immich.client.models.check_existing_assets_dto import (
    CheckExistingAssetsDto as CheckExistingAssetsDto,
)
from immich.client.models.check_existing_assets_response_dto import (
    CheckExistingAssetsResponseDto as CheckExistingAssetsResponseDto,
)
from immich.client.models.colorspace import Colorspace as Colorspace
from immich.client.models.contributor_count_response_dto import (
    ContributorCountResponseDto as ContributorCountResponseDto,
)
from immich.client.models.create_album_dto import CreateAlbumDto as CreateAlbumDto
from immich.client.models.create_library_dto import CreateLibraryDto as CreateLibraryDto
from immich.client.models.create_profile_image_response_dto import (
    CreateProfileImageResponseDto as CreateProfileImageResponseDto,
)
from immich.client.models.database_backup_config import (
    DatabaseBackupConfig as DatabaseBackupConfig,
)
from immich.client.models.download_archive_info import (
    DownloadArchiveInfo as DownloadArchiveInfo,
)
from immich.client.models.download_info_dto import DownloadInfoDto as DownloadInfoDto
from immich.client.models.download_response import DownloadResponse as DownloadResponse
from immich.client.models.download_response_dto import (
    DownloadResponseDto as DownloadResponseDto,
)
from immich.client.models.download_update import DownloadUpdate as DownloadUpdate
from immich.client.models.duplicate_detection_config import (
    DuplicateDetectionConfig as DuplicateDetectionConfig,
)
from immich.client.models.duplicate_response_dto import (
    DuplicateResponseDto as DuplicateResponseDto,
)
from immich.client.models.email_notifications_response import (
    EmailNotificationsResponse as EmailNotificationsResponse,
)
from immich.client.models.email_notifications_update import (
    EmailNotificationsUpdate as EmailNotificationsUpdate,
)
from immich.client.models.exif_response_dto import ExifResponseDto as ExifResponseDto
from immich.client.models.face_dto import FaceDto as FaceDto
from immich.client.models.facial_recognition_config import (
    FacialRecognitionConfig as FacialRecognitionConfig,
)
from immich.client.models.folders_response import FoldersResponse as FoldersResponse
from immich.client.models.folders_update import FoldersUpdate as FoldersUpdate
from immich.client.models.image_format import ImageFormat as ImageFormat
from immich.client.models.job_create_dto import JobCreateDto as JobCreateDto
from immich.client.models.job_name import JobName as JobName
from immich.client.models.job_settings_dto import JobSettingsDto as JobSettingsDto
from immich.client.models.library_response_dto import (
    LibraryResponseDto as LibraryResponseDto,
)
from immich.client.models.library_stats_response_dto import (
    LibraryStatsResponseDto as LibraryStatsResponseDto,
)
from immich.client.models.license_key_dto import LicenseKeyDto as LicenseKeyDto
from immich.client.models.license_response_dto import (
    LicenseResponseDto as LicenseResponseDto,
)
from immich.client.models.log_level import LogLevel as LogLevel
from immich.client.models.login_credential_dto import (
    LoginCredentialDto as LoginCredentialDto,
)
from immich.client.models.login_response_dto import LoginResponseDto as LoginResponseDto
from immich.client.models.logout_response_dto import (
    LogoutResponseDto as LogoutResponseDto,
)
from immich.client.models.machine_learning_availability_checks_dto import (
    MachineLearningAvailabilityChecksDto as MachineLearningAvailabilityChecksDto,
)
from immich.client.models.maintenance_action import (
    MaintenanceAction as MaintenanceAction,
)
from immich.client.models.maintenance_auth_dto import (
    MaintenanceAuthDto as MaintenanceAuthDto,
)
from immich.client.models.maintenance_login_dto import (
    MaintenanceLoginDto as MaintenanceLoginDto,
)
from immich.client.models.manual_job_name import ManualJobName as ManualJobName
from immich.client.models.map_marker_response_dto import (
    MapMarkerResponseDto as MapMarkerResponseDto,
)
from immich.client.models.map_reverse_geocode_response_dto import (
    MapReverseGeocodeResponseDto as MapReverseGeocodeResponseDto,
)
from immich.client.models.memories_response import MemoriesResponse as MemoriesResponse
from immich.client.models.memories_update import MemoriesUpdate as MemoriesUpdate
from immich.client.models.memory_create_dto import MemoryCreateDto as MemoryCreateDto
from immich.client.models.memory_response_dto import (
    MemoryResponseDto as MemoryResponseDto,
)
from immich.client.models.memory_search_order import (
    MemorySearchOrder as MemorySearchOrder,
)
from immich.client.models.memory_statistics_response_dto import (
    MemoryStatisticsResponseDto as MemoryStatisticsResponseDto,
)
from immich.client.models.memory_type import MemoryType as MemoryType
from immich.client.models.memory_update_dto import MemoryUpdateDto as MemoryUpdateDto
from immich.client.models.merge_person_dto import MergePersonDto as MergePersonDto
from immich.client.models.metadata_search_dto import (
    MetadataSearchDto as MetadataSearchDto,
)
from immich.client.models.notification_create_dto import (
    NotificationCreateDto as NotificationCreateDto,
)
from immich.client.models.notification_delete_all_dto import (
    NotificationDeleteAllDto as NotificationDeleteAllDto,
)
from immich.client.models.notification_dto import NotificationDto as NotificationDto
from immich.client.models.notification_level import (
    NotificationLevel as NotificationLevel,
)
from immich.client.models.notification_type import NotificationType as NotificationType
from immich.client.models.notification_update_all_dto import (
    NotificationUpdateAllDto as NotificationUpdateAllDto,
)
from immich.client.models.notification_update_dto import (
    NotificationUpdateDto as NotificationUpdateDto,
)
from immich.client.models.o_auth_authorize_response_dto import (
    OAuthAuthorizeResponseDto as OAuthAuthorizeResponseDto,
)
from immich.client.models.o_auth_callback_dto import (
    OAuthCallbackDto as OAuthCallbackDto,
)
from immich.client.models.o_auth_config_dto import OAuthConfigDto as OAuthConfigDto
from immich.client.models.o_auth_token_endpoint_auth_method import (
    OAuthTokenEndpointAuthMethod as OAuthTokenEndpointAuthMethod,
)
from immich.client.models.ocr_config import OcrConfig as OcrConfig
from immich.client.models.on_this_day_dto import OnThisDayDto as OnThisDayDto
from immich.client.models.onboarding_dto import OnboardingDto as OnboardingDto
from immich.client.models.onboarding_response_dto import (
    OnboardingResponseDto as OnboardingResponseDto,
)
from immich.client.models.partner_create_dto import PartnerCreateDto as PartnerCreateDto
from immich.client.models.partner_direction import PartnerDirection as PartnerDirection
from immich.client.models.partner_response_dto import (
    PartnerResponseDto as PartnerResponseDto,
)
from immich.client.models.partner_update_dto import PartnerUpdateDto as PartnerUpdateDto
from immich.client.models.people_response import PeopleResponse as PeopleResponse
from immich.client.models.people_response_dto import (
    PeopleResponseDto as PeopleResponseDto,
)
from immich.client.models.people_update import PeopleUpdate as PeopleUpdate
from immich.client.models.people_update_dto import PeopleUpdateDto as PeopleUpdateDto
from immich.client.models.people_update_item import PeopleUpdateItem as PeopleUpdateItem
from immich.client.models.permission import Permission as Permission
from immich.client.models.person_create_dto import PersonCreateDto as PersonCreateDto
from immich.client.models.person_response_dto import (
    PersonResponseDto as PersonResponseDto,
)
from immich.client.models.person_statistics_response_dto import (
    PersonStatisticsResponseDto as PersonStatisticsResponseDto,
)
from immich.client.models.person_update_dto import PersonUpdateDto as PersonUpdateDto
from immich.client.models.person_with_faces_response_dto import (
    PersonWithFacesResponseDto as PersonWithFacesResponseDto,
)
from immich.client.models.pin_code_change_dto import (
    PinCodeChangeDto as PinCodeChangeDto,
)
from immich.client.models.pin_code_reset_dto import PinCodeResetDto as PinCodeResetDto
from immich.client.models.pin_code_setup_dto import PinCodeSetupDto as PinCodeSetupDto
from immich.client.models.places_response_dto import (
    PlacesResponseDto as PlacesResponseDto,
)
from immich.client.models.plugin_action_response_dto import (
    PluginActionResponseDto as PluginActionResponseDto,
)
from immich.client.models.plugin_context_type import (
    PluginContextType as PluginContextType,
)
from immich.client.models.plugin_filter_response_dto import (
    PluginFilterResponseDto as PluginFilterResponseDto,
)
from immich.client.models.plugin_response_dto import (
    PluginResponseDto as PluginResponseDto,
)
from immich.client.models.plugin_trigger_response_dto import (
    PluginTriggerResponseDto as PluginTriggerResponseDto,
)
from immich.client.models.plugin_trigger_type import (
    PluginTriggerType as PluginTriggerType,
)
from immich.client.models.purchase_response import PurchaseResponse as PurchaseResponse
from immich.client.models.purchase_update import PurchaseUpdate as PurchaseUpdate
from immich.client.models.queue_command import QueueCommand as QueueCommand
from immich.client.models.queue_command_dto import QueueCommandDto as QueueCommandDto
from immich.client.models.queue_delete_dto import QueueDeleteDto as QueueDeleteDto
from immich.client.models.queue_job_response_dto import (
    QueueJobResponseDto as QueueJobResponseDto,
)
from immich.client.models.queue_job_status import QueueJobStatus as QueueJobStatus
from immich.client.models.queue_name import QueueName as QueueName
from immich.client.models.queue_response_dto import QueueResponseDto as QueueResponseDto
from immich.client.models.queue_response_legacy_dto import (
    QueueResponseLegacyDto as QueueResponseLegacyDto,
)
from immich.client.models.queue_statistics_dto import (
    QueueStatisticsDto as QueueStatisticsDto,
)
from immich.client.models.queue_status_legacy_dto import (
    QueueStatusLegacyDto as QueueStatusLegacyDto,
)
from immich.client.models.queue_update_dto import QueueUpdateDto as QueueUpdateDto
from immich.client.models.queues_response_legacy_dto import (
    QueuesResponseLegacyDto as QueuesResponseLegacyDto,
)
from immich.client.models.random_search_dto import RandomSearchDto as RandomSearchDto
from immich.client.models.ratings_response import RatingsResponse as RatingsResponse
from immich.client.models.ratings_update import RatingsUpdate as RatingsUpdate
from immich.client.models.reaction_level import ReactionLevel as ReactionLevel
from immich.client.models.reaction_type import ReactionType as ReactionType
from immich.client.models.reverse_geocoding_state_response_dto import (
    ReverseGeocodingStateResponseDto as ReverseGeocodingStateResponseDto,
)
from immich.client.models.search_album_response_dto import (
    SearchAlbumResponseDto as SearchAlbumResponseDto,
)
from immich.client.models.search_asset_response_dto import (
    SearchAssetResponseDto as SearchAssetResponseDto,
)
from immich.client.models.search_explore_item import (
    SearchExploreItem as SearchExploreItem,
)
from immich.client.models.search_explore_response_dto import (
    SearchExploreResponseDto as SearchExploreResponseDto,
)
from immich.client.models.search_facet_count_response_dto import (
    SearchFacetCountResponseDto as SearchFacetCountResponseDto,
)
from immich.client.models.search_facet_response_dto import (
    SearchFacetResponseDto as SearchFacetResponseDto,
)
from immich.client.models.search_response_dto import (
    SearchResponseDto as SearchResponseDto,
)
from immich.client.models.search_statistics_response_dto import (
    SearchStatisticsResponseDto as SearchStatisticsResponseDto,
)
from immich.client.models.search_suggestion_type import (
    SearchSuggestionType as SearchSuggestionType,
)
from immich.client.models.server_about_response_dto import (
    ServerAboutResponseDto as ServerAboutResponseDto,
)
from immich.client.models.server_apk_links_dto import (
    ServerApkLinksDto as ServerApkLinksDto,
)
from immich.client.models.server_config_dto import ServerConfigDto as ServerConfigDto
from immich.client.models.server_features_dto import (
    ServerFeaturesDto as ServerFeaturesDto,
)
from immich.client.models.server_media_types_response_dto import (
    ServerMediaTypesResponseDto as ServerMediaTypesResponseDto,
)
from immich.client.models.server_ping_response import (
    ServerPingResponse as ServerPingResponse,
)
from immich.client.models.server_stats_response_dto import (
    ServerStatsResponseDto as ServerStatsResponseDto,
)
from immich.client.models.server_storage_response_dto import (
    ServerStorageResponseDto as ServerStorageResponseDto,
)
from immich.client.models.server_theme_dto import ServerThemeDto as ServerThemeDto
from immich.client.models.server_version_history_response_dto import (
    ServerVersionHistoryResponseDto as ServerVersionHistoryResponseDto,
)
from immich.client.models.server_version_response_dto import (
    ServerVersionResponseDto as ServerVersionResponseDto,
)
from immich.client.models.session_create_dto import SessionCreateDto as SessionCreateDto
from immich.client.models.session_create_response_dto import (
    SessionCreateResponseDto as SessionCreateResponseDto,
)
from immich.client.models.session_response_dto import (
    SessionResponseDto as SessionResponseDto,
)
from immich.client.models.session_unlock_dto import SessionUnlockDto as SessionUnlockDto
from immich.client.models.session_update_dto import SessionUpdateDto as SessionUpdateDto
from immich.client.models.set_maintenance_mode_dto import (
    SetMaintenanceModeDto as SetMaintenanceModeDto,
)
from immich.client.models.shared_link_create_dto import (
    SharedLinkCreateDto as SharedLinkCreateDto,
)
from immich.client.models.shared_link_edit_dto import (
    SharedLinkEditDto as SharedLinkEditDto,
)
from immich.client.models.shared_link_response_dto import (
    SharedLinkResponseDto as SharedLinkResponseDto,
)
from immich.client.models.shared_link_type import SharedLinkType as SharedLinkType
from immich.client.models.shared_links_response import (
    SharedLinksResponse as SharedLinksResponse,
)
from immich.client.models.shared_links_update import (
    SharedLinksUpdate as SharedLinksUpdate,
)
from immich.client.models.sign_up_dto import SignUpDto as SignUpDto
from immich.client.models.smart_search_dto import SmartSearchDto as SmartSearchDto
from immich.client.models.source_type import SourceType as SourceType
from immich.client.models.stack_create_dto import StackCreateDto as StackCreateDto
from immich.client.models.stack_response_dto import StackResponseDto as StackResponseDto
from immich.client.models.stack_update_dto import StackUpdateDto as StackUpdateDto
from immich.client.models.statistics_search_dto import (
    StatisticsSearchDto as StatisticsSearchDto,
)
from immich.client.models.sync_ack_delete_dto import (
    SyncAckDeleteDto as SyncAckDeleteDto,
)
from immich.client.models.sync_ack_dto import SyncAckDto as SyncAckDto
from immich.client.models.sync_ack_set_dto import SyncAckSetDto as SyncAckSetDto
from immich.client.models.sync_album_delete_v1 import (
    SyncAlbumDeleteV1 as SyncAlbumDeleteV1,
)
from immich.client.models.sync_album_to_asset_delete_v1 import (
    SyncAlbumToAssetDeleteV1 as SyncAlbumToAssetDeleteV1,
)
from immich.client.models.sync_album_to_asset_v1 import (
    SyncAlbumToAssetV1 as SyncAlbumToAssetV1,
)
from immich.client.models.sync_album_user_delete_v1 import (
    SyncAlbumUserDeleteV1 as SyncAlbumUserDeleteV1,
)
from immich.client.models.sync_album_user_v1 import SyncAlbumUserV1 as SyncAlbumUserV1
from immich.client.models.sync_album_v1 import SyncAlbumV1 as SyncAlbumV1
from immich.client.models.sync_asset_delete_v1 import (
    SyncAssetDeleteV1 as SyncAssetDeleteV1,
)
from immich.client.models.sync_asset_exif_v1 import SyncAssetExifV1 as SyncAssetExifV1
from immich.client.models.sync_asset_face_delete_v1 import (
    SyncAssetFaceDeleteV1 as SyncAssetFaceDeleteV1,
)
from immich.client.models.sync_asset_face_v1 import SyncAssetFaceV1 as SyncAssetFaceV1
from immich.client.models.sync_asset_metadata_delete_v1 import (
    SyncAssetMetadataDeleteV1 as SyncAssetMetadataDeleteV1,
)
from immich.client.models.sync_asset_metadata_v1 import (
    SyncAssetMetadataV1 as SyncAssetMetadataV1,
)
from immich.client.models.sync_asset_v1 import SyncAssetV1 as SyncAssetV1
from immich.client.models.sync_auth_user_v1 import SyncAuthUserV1 as SyncAuthUserV1
from immich.client.models.sync_entity_type import SyncEntityType as SyncEntityType
from immich.client.models.sync_memory_asset_delete_v1 import (
    SyncMemoryAssetDeleteV1 as SyncMemoryAssetDeleteV1,
)
from immich.client.models.sync_memory_asset_v1 import (
    SyncMemoryAssetV1 as SyncMemoryAssetV1,
)
from immich.client.models.sync_memory_delete_v1 import (
    SyncMemoryDeleteV1 as SyncMemoryDeleteV1,
)
from immich.client.models.sync_memory_v1 import SyncMemoryV1 as SyncMemoryV1
from immich.client.models.sync_partner_delete_v1 import (
    SyncPartnerDeleteV1 as SyncPartnerDeleteV1,
)
from immich.client.models.sync_partner_v1 import SyncPartnerV1 as SyncPartnerV1
from immich.client.models.sync_person_delete_v1 import (
    SyncPersonDeleteV1 as SyncPersonDeleteV1,
)
from immich.client.models.sync_person_v1 import SyncPersonV1 as SyncPersonV1
from immich.client.models.sync_request_type import SyncRequestType as SyncRequestType
from immich.client.models.sync_stack_delete_v1 import (
    SyncStackDeleteV1 as SyncStackDeleteV1,
)
from immich.client.models.sync_stack_v1 import SyncStackV1 as SyncStackV1
from immich.client.models.sync_stream_dto import SyncStreamDto as SyncStreamDto
from immich.client.models.sync_user_delete_v1 import (
    SyncUserDeleteV1 as SyncUserDeleteV1,
)
from immich.client.models.sync_user_metadata_delete_v1 import (
    SyncUserMetadataDeleteV1 as SyncUserMetadataDeleteV1,
)
from immich.client.models.sync_user_metadata_v1 import (
    SyncUserMetadataV1 as SyncUserMetadataV1,
)
from immich.client.models.sync_user_v1 import SyncUserV1 as SyncUserV1
from immich.client.models.system_config_backups_dto import (
    SystemConfigBackupsDto as SystemConfigBackupsDto,
)
from immich.client.models.system_config_dto import SystemConfigDto as SystemConfigDto
from immich.client.models.system_config_f_fmpeg_dto import (
    SystemConfigFFmpegDto as SystemConfigFFmpegDto,
)
from immich.client.models.system_config_faces_dto import (
    SystemConfigFacesDto as SystemConfigFacesDto,
)
from immich.client.models.system_config_generated_fullsize_image_dto import (
    SystemConfigGeneratedFullsizeImageDto as SystemConfigGeneratedFullsizeImageDto,
)
from immich.client.models.system_config_generated_image_dto import (
    SystemConfigGeneratedImageDto as SystemConfigGeneratedImageDto,
)
from immich.client.models.system_config_image_dto import (
    SystemConfigImageDto as SystemConfigImageDto,
)
from immich.client.models.system_config_job_dto import (
    SystemConfigJobDto as SystemConfigJobDto,
)
from immich.client.models.system_config_library_dto import (
    SystemConfigLibraryDto as SystemConfigLibraryDto,
)
from immich.client.models.system_config_library_scan_dto import (
    SystemConfigLibraryScanDto as SystemConfigLibraryScanDto,
)
from immich.client.models.system_config_library_watch_dto import (
    SystemConfigLibraryWatchDto as SystemConfigLibraryWatchDto,
)
from immich.client.models.system_config_logging_dto import (
    SystemConfigLoggingDto as SystemConfigLoggingDto,
)
from immich.client.models.system_config_machine_learning_dto import (
    SystemConfigMachineLearningDto as SystemConfigMachineLearningDto,
)
from immich.client.models.system_config_map_dto import (
    SystemConfigMapDto as SystemConfigMapDto,
)
from immich.client.models.system_config_metadata_dto import (
    SystemConfigMetadataDto as SystemConfigMetadataDto,
)
from immich.client.models.system_config_new_version_check_dto import (
    SystemConfigNewVersionCheckDto as SystemConfigNewVersionCheckDto,
)
from immich.client.models.system_config_nightly_tasks_dto import (
    SystemConfigNightlyTasksDto as SystemConfigNightlyTasksDto,
)
from immich.client.models.system_config_notifications_dto import (
    SystemConfigNotificationsDto as SystemConfigNotificationsDto,
)
from immich.client.models.system_config_o_auth_dto import (
    SystemConfigOAuthDto as SystemConfigOAuthDto,
)
from immich.client.models.system_config_password_login_dto import (
    SystemConfigPasswordLoginDto as SystemConfigPasswordLoginDto,
)
from immich.client.models.system_config_reverse_geocoding_dto import (
    SystemConfigReverseGeocodingDto as SystemConfigReverseGeocodingDto,
)
from immich.client.models.system_config_server_dto import (
    SystemConfigServerDto as SystemConfigServerDto,
)
from immich.client.models.system_config_smtp_dto import (
    SystemConfigSmtpDto as SystemConfigSmtpDto,
)
from immich.client.models.system_config_smtp_transport_dto import (
    SystemConfigSmtpTransportDto as SystemConfigSmtpTransportDto,
)
from immich.client.models.system_config_storage_template_dto import (
    SystemConfigStorageTemplateDto as SystemConfigStorageTemplateDto,
)
from immich.client.models.system_config_template_emails_dto import (
    SystemConfigTemplateEmailsDto as SystemConfigTemplateEmailsDto,
)
from immich.client.models.system_config_template_storage_option_dto import (
    SystemConfigTemplateStorageOptionDto as SystemConfigTemplateStorageOptionDto,
)
from immich.client.models.system_config_templates_dto import (
    SystemConfigTemplatesDto as SystemConfigTemplatesDto,
)
from immich.client.models.system_config_theme_dto import (
    SystemConfigThemeDto as SystemConfigThemeDto,
)
from immich.client.models.system_config_trash_dto import (
    SystemConfigTrashDto as SystemConfigTrashDto,
)
from immich.client.models.system_config_user_dto import (
    SystemConfigUserDto as SystemConfigUserDto,
)
from immich.client.models.tag_bulk_assets_dto import (
    TagBulkAssetsDto as TagBulkAssetsDto,
)
from immich.client.models.tag_bulk_assets_response_dto import (
    TagBulkAssetsResponseDto as TagBulkAssetsResponseDto,
)
from immich.client.models.tag_create_dto import TagCreateDto as TagCreateDto
from immich.client.models.tag_response_dto import TagResponseDto as TagResponseDto
from immich.client.models.tag_update_dto import TagUpdateDto as TagUpdateDto
from immich.client.models.tag_upsert_dto import TagUpsertDto as TagUpsertDto
from immich.client.models.tags_response import TagsResponse as TagsResponse
from immich.client.models.tags_update import TagsUpdate as TagsUpdate
from immich.client.models.template_dto import TemplateDto as TemplateDto
from immich.client.models.template_response_dto import (
    TemplateResponseDto as TemplateResponseDto,
)
from immich.client.models.test_email_response_dto import (
    TestEmailResponseDto as TestEmailResponseDto,
)
from immich.client.models.time_bucket_asset_response_dto import (
    TimeBucketAssetResponseDto as TimeBucketAssetResponseDto,
)
from immich.client.models.time_buckets_response_dto import (
    TimeBucketsResponseDto as TimeBucketsResponseDto,
)
from immich.client.models.tone_mapping import ToneMapping as ToneMapping
from immich.client.models.transcode_hw_accel import TranscodeHWAccel as TranscodeHWAccel
from immich.client.models.transcode_policy import TranscodePolicy as TranscodePolicy
from immich.client.models.trash_response_dto import TrashResponseDto as TrashResponseDto
from immich.client.models.update_album_dto import UpdateAlbumDto as UpdateAlbumDto
from immich.client.models.update_album_user_dto import (
    UpdateAlbumUserDto as UpdateAlbumUserDto,
)
from immich.client.models.update_asset_dto import UpdateAssetDto as UpdateAssetDto
from immich.client.models.update_library_dto import UpdateLibraryDto as UpdateLibraryDto
from immich.client.models.usage_by_user_dto import UsageByUserDto as UsageByUserDto
from immich.client.models.user_admin_create_dto import (
    UserAdminCreateDto as UserAdminCreateDto,
)
from immich.client.models.user_admin_delete_dto import (
    UserAdminDeleteDto as UserAdminDeleteDto,
)
from immich.client.models.user_admin_response_dto import (
    UserAdminResponseDto as UserAdminResponseDto,
)
from immich.client.models.user_admin_update_dto import (
    UserAdminUpdateDto as UserAdminUpdateDto,
)
from immich.client.models.user_avatar_color import UserAvatarColor as UserAvatarColor
from immich.client.models.user_license import UserLicense as UserLicense
from immich.client.models.user_metadata_key import UserMetadataKey as UserMetadataKey
from immich.client.models.user_preferences_response_dto import (
    UserPreferencesResponseDto as UserPreferencesResponseDto,
)
from immich.client.models.user_preferences_update_dto import (
    UserPreferencesUpdateDto as UserPreferencesUpdateDto,
)
from immich.client.models.user_response_dto import UserResponseDto as UserResponseDto
from immich.client.models.user_status import UserStatus as UserStatus
from immich.client.models.user_update_me_dto import UserUpdateMeDto as UserUpdateMeDto
from immich.client.models.validate_access_token_response_dto import (
    ValidateAccessTokenResponseDto as ValidateAccessTokenResponseDto,
)
from immich.client.models.validate_library_dto import (
    ValidateLibraryDto as ValidateLibraryDto,
)
from immich.client.models.validate_library_import_path_response_dto import (
    ValidateLibraryImportPathResponseDto as ValidateLibraryImportPathResponseDto,
)
from immich.client.models.validate_library_response_dto import (
    ValidateLibraryResponseDto as ValidateLibraryResponseDto,
)
from immich.client.models.version_check_state_response_dto import (
    VersionCheckStateResponseDto as VersionCheckStateResponseDto,
)
from immich.client.models.video_codec import VideoCodec as VideoCodec
from immich.client.models.video_container import VideoContainer as VideoContainer
from immich.client.models.workflow_action_item_dto import (
    WorkflowActionItemDto as WorkflowActionItemDto,
)
from immich.client.models.workflow_action_response_dto import (
    WorkflowActionResponseDto as WorkflowActionResponseDto,
)
from immich.client.models.workflow_create_dto import (
    WorkflowCreateDto as WorkflowCreateDto,
)
from immich.client.models.workflow_filter_item_dto import (
    WorkflowFilterItemDto as WorkflowFilterItemDto,
)
from immich.client.models.workflow_filter_response_dto import (
    WorkflowFilterResponseDto as WorkflowFilterResponseDto,
)
from immich.client.models.workflow_response_dto import (
    WorkflowResponseDto as WorkflowResponseDto,
)
from immich.client.models.workflow_update_dto import (
    WorkflowUpdateDto as WorkflowUpdateDto,
)
